Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(420)

Unified Diff: runtime/observatory/lib/src/models/objects/isolate.dart

Issue 2762323002: Reimplemented zone memory tracking to avoid race conditions that were causing crashes in the previo… (Closed)
Patch Set: Final change Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: runtime/observatory/lib/src/models/objects/isolate.dart
diff --git a/runtime/observatory/lib/src/models/objects/isolate.dart b/runtime/observatory/lib/src/models/objects/isolate.dart
index 8c1e3672390d3024b7d34140b5f67911f6464c20..f1d1147f8c5917f6d1433ed6555605014d6731ad 100644
--- a/runtime/observatory/lib/src/models/objects/isolate.dart
+++ b/runtime/observatory/lib/src/models/objects/isolate.dart
@@ -54,10 +54,10 @@ abstract class Isolate extends IsolateRef {
/// The list of threads associated with this isolate.
Iterable<Thread> get threads;
/// The maximum amount of memory in bytes allocated by the isolate in all
/// threads at a given time. Calculated using the high watermarks of each
/// thread alive when a thread is unscheduled.
- int get memoryHighWatermark;
+ int get zoneHighWatermark;
/// The number of zone handles currently held by this isolate.
int get numZoneHandles;
« no previous file with comments | « runtime/observatory/lib/src/elements/isolate_view.dart ('k') | runtime/observatory/lib/src/models/objects/thread.dart » ('j') | no next file with comments »
@@ -54,10 +54,10 @@ abstract class Isolate extends IsolateRef {
/// The list of threads associated with this isolate.
Iterable<Thread> get threads;
- /// The maximum amount of memory in bytes allocated by the isolate in all
- /// threads at a given time. Calculated using the high watermarks of each
+ /// The maximum amount of zone memory in bytes allocated by the isolate in
+ /// all threads at a given time. Calculated using the high watermarks of each
/// thread alive when a thread is unscheduled.

Powered by Google App Engine
This is Rietveld 408576698